==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebCardDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardDescription } from "./WebCardDescription";
/**
 * @hidden
 */
var WebCardDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCardDescriptionMetadata, _super);
    function WebCardDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCardDescriptionMetadata.b = function (a) {
        if (WebCardDescriptionMetadata.a == null) {
            WebCardDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCardDescriptionMetadata.c(WebCardDescriptionMetadata.a);
        }
        if (a.j(WebCardDescriptionMetadata.a)) {
            return;
        }
        a.y(WebCardDescriptionMetadata.a);
    };
    WebCardDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Card");
        a.item("__tagNameWC", "String:igc-card");
        a.item("Elevated", "Boolean");
    };
    WebCardDescriptionMetadata.d = function (a) {
        WebCardDescriptionMetadata.b(a);
        a.aa("WebCard", function () { return new WebCardDescription(); });
        a.z("WebCard", WebCardDescriptionMetadata.a);
    };
    WebCardDescriptionMetadata.$t = markType(WebCardDescriptionMetadata, 'WebCardDescriptionMetadata');
    WebCardDescriptionMetadata.a = null;
    return WebCardDescriptionMetadata;
}(Base));
export { WebCardDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebCardDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardDescription } from "./WebCardDescription";
/**
 * @hidden
 */
var WebCardDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCardDescriptionMetadata, _super);
    function WebCardDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCardDescriptionMetadata.b = function (a) {
        if (WebCardDescriptionMetadata.a == null) {
            WebCardDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCardDescriptionMetadata.c(WebCardDescriptionMetadata.a);
        }
        if (a.k(WebCardDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebCardDescriptionMetadata.a);
    };
    WebCardDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Card");
        a.item("__tagNameWC", "String:igc-card");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Elevated", "Boolean");
    };
    WebCardDescriptionMetadata.d = function (a) {
        WebCardDescriptionMetadata.b(a);
        a.ac("WebCard", function () { return new WebCardDescription(); });
        a.ab("WebCard", WebCardDescriptionMetadata.a);
    };
    WebCardDescriptionMetadata.$t = markType(WebCardDescriptionMetadata, 'WebCardDescriptionMetadata');
    WebCardDescriptionMetadata.a = null;
    return WebCardDescriptionMetadata;
}(Base));
export { WebCardDescriptionMetadata };
